-- local A, C, L = select(2, ...):unpack()
 local ObjectiveTracker = CreateFrame("Frame")
-- local Misc = A["Misc"]

-- Lib Globals
local _G = _G
local unpack = unpack
local select = select

-- WoW Globals
local ObjectiveTrackerFrame = _G["ObjectiveTrackerFrame"]
local MinimizeButton = ObjectiveTrackerFrame.HeaderMenu.MinimizeButton
local MinimizeButtonTitle = ObjectiveTrackerFrame.HeaderMenu.Title
local SCENARIO_CONTENT_TRACKER_MODULE = SCENARIO_CONTENT_TRACKER_MODULE
local QUEST_TRACKER_MODULE = QUEST_TRACKER_MODULE
local WORLD_QUEST_TRACKER_MODULE = WORLD_QUEST_TRACKER_MODULE
local DEFAULT_OBJECTIVE_TRACKER_MODULE = DEFAULT_OBJECTIVE_TRACKER_MODULE
local BONUS_OBJECTIVE_TRACKER_MODULE = BONUS_OBJECTIVE_TRACKER_MODULE
local SCENARIO_TRACKER_MODULE = SCENARIO_TRACKER_MODULE

function ObjectiveTracker:OnEnter()
	self:SetFadeInTemplate(1, 1)
	self.Backdrop:SetColor(1,0,0,0.25)
end

function ObjectiveTracker:OnLeave()
	self:SetFadeOutTemplate(1, 0)
	self.Backdrop:SetColor(1,0,0,0.25)
end

function ObjectiveTracker:OnClick()
	if (ObjectiveTrackerFrame.collapsed) then		
		self.Texture:Point("CENTER", self, 2, 0)
		self.Texture:SetTexture("Interface\\Addons\\InkedSV_QuestTracker\\assests\\ArrowLeft")
	else		
		self.Texture:Point("CENTER", self, -2, 0)
		self.Texture:SetTexture("Interface\\Addons\\InkedSV_QuestTracker\\assests\\ArrowLeft")
	end
end

function ObjectiveTracker:CreateToggleButtons()
	--MinimizeButtonTitle:SetParent(A.HiddenFrame)

	-- MinimizeButton:Size(16, 352)
	-- MinimizeButton:ClearAllPoints()
	-- MinimizeButton:Point("RIGHT", UIParent, -6, 0)
	-- MinimizeButton:CreateBackdrop()
	-- MinimizeButton:CreateShadow()
	-- MinimizeButton:SetNormalTexture("")
	-- MinimizeButton:SetHighlightTexture("")
	-- MinimizeButton:SetPushedTexture("")
	-- MinimizeButton:SetDisabledTexture("")
	
	-- MinimizeButton.Texture = MinimizeButton:CreateTexture(nil, "OVERLAY")
	-- MinimizeButton.Texture:Size(14, 14)
	-- MinimizeButton.Texture:Point("CENTER", MinimizeButton, -2, 0)
	-- MinimizeButton.Texture:SetVertexColor(unpack(A.GetClassColors))
	-- MinimizeButton.Texture:SetTexture(C.Media.PowerArrowRight)

	-- MinimizeButton:HookScript("OnClick", self.OnClick)
	-- MinimizeButton:SetScript("OnEnter", self.OnEnter)
	-- MinimizeButton:SetScript("OnLeave", self.OnLeave)

	-- MinimizeButton:SetAlpha(0)
end

function ObjectiveTracker:SetPoint()
	local GetTop = ObjectiveTrackerFrame:GetTop() or 0
	local ScreenHeight = GetScreenHeight()
	local GapFromTop = ScreenHeight - GetTop
	local MaxHeight = ScreenHeight - GapFromTop
	local SetObjectiveFrameHeight = min(MaxHeight, 480)

	local ObjectiveFrameHolder = CreateFrame("Frame", nil, UIParent)
	ObjectiveFrameHolder:Size(130, 22)
	ObjectiveFrameHolder:Point("TOPRIGHT", UIParent, -72, -242)

	ObjectiveTrackerFrame:ClearAllPoints()
	ObjectiveTrackerFrame:Point("TOP", ObjectiveFrameHolder)
	ObjectiveTrackerFrame:Height(SetObjectiveFrameHeight)

	hooksecurefunc(ObjectiveTrackerFrame, "SetPoint", function(_,_, Parent)
		if (Parent ~= ObjectiveFrameHolder) then
			ObjectiveTrackerFrame:ClearAllPoints()
			ObjectiveTrackerFrame:Point("TOP", ObjectiveFrameHolder, 0, 0)
		end
	end)
end

function ObjectiveTracker:Skin()
	local Frame = ObjectiveTrackerFrame.MODULES

	if (Frame) then
		for i = 1, #Frame do
			local Modules = Frame[i]

			if (Modules) then
				local Header = Modules.Header
				Header:SetFrameStrata("MEDIUM")
				Header:SetFrameLevel(10)
				
				local Background = Modules.Header.Background
				Background:SetAtlas(nil)
			
				local Text = Modules.Header.Text
				Text:SetFontTemplate("Default", 16)
				Text:SetDrawLayer("OVERLAY", 7)
				Text:SetParent(Header)

				if not (Modules.IsSkinned) then			
					local HeaderPanel = CreateFrame("Frame", nil, Header)
					HeaderPanel:SetFrameLevel(Header:GetFrameLevel() - 1)
					HeaderPanel:SetFrameStrata("BACKGROUND")
					HeaderPanel:SetOutside(Header, 1, 1)

					local HeaderBar = CreateFrame("StatusBar", nil, HeaderPanel)
					HeaderBar:Size(232, 4)
					HeaderBar:Point("CENTER", HeaderPanel, -6, -9)
					HeaderBar:SetStatusBarTexture(C.Media.Blank)
					HeaderBar:SetStatusBarColor(unpack(A.GetClassColors))
					HeaderBar:SetTemplate()
				
					local Shadow = CreateFrame("Frame", nil, HeaderBar)
					Shadow:SetFrameLevel(HeaderBar:GetFrameLevel() -1)
					Shadow:SetOutside(HeaderBar, 3, 3)
					Shadow:SetBackdrop({
						edgeFile = C.Media.Shadow, edgeSize = A:Scale(3),
					})
					Shadow:SetBackdropBorderColor(C.General.ShadowColor[1], C.General.ShadowColor[2], C.General.ShadowColor[3], 0.20)
					Shadow:SetScale(A:Scale(3))
					
					Modules.IsSkinned = true
				end
			end
		end
	end
	
	local NumQuests, Quests, Objectives
	local ObjectiveTrackerBlocksFrame = _G["ObjectiveTrackerBlocksFrame"]
	local ObjectiveTrackerFrame = _G["ObjectiveTrackerFrame"]

	if not InCombatLockdown() then
		NumQuests = select(2, GetNumQuestLogEntries())

		if (NumQuests >= (MAX_QUESTS - 5)) then
			Quests = format("|cffff0000%d/%d|r - %s", NumQuests, MAX_QUESTS, TRACKER_HEADER_QUESTS)
			Objectives = format("|cffff0000%d/%d|r - %s", NumQuests, MAX_QUESTS, OBJECTIVES_TRACKER_LABEL)
		else
			Quests = format("%d/%d - %s", NumQuests, MAX_QUESTS, TRACKER_HEADER_QUESTS)
			Objectives = format("%d/%d - %s", NumQuests, MAX_QUESTS, OBJECTIVES_TRACKER_LABEL)
		end
	
		ObjectiveTrackerBlocksFrame.QuestHeader.Text:SetText(Quests)
		ObjectiveTrackerFrame.HeaderMenu.Title:SetText(Objectives)
	end
end

function ObjectiveTracker:SkinScenario()
	local StageBlock = _G["ScenarioStageBlock"]
	StageBlock:StripTexture()
	--StageBlock:SetHeight(50)

	local StageText = StageBlock.Stage
	--StageText:SetHeight(14)
	StageText:SetFontTemplate("Default", 16)

	local NameText = StageBlock.Name
	NameText:SetFontTemplate("Default", 14)
end

function ObjectiveTracker:UpdateQuestItem(block)
	local QuestItemButton = block.itemButton
	
	if (QuestItemButton) then
		local Icon = QuestItemButton.icon
		local Count = QuestItemButton.Count
	
		if not (QuestItemButton.IsSkinned) then
			QuestItemButton:Size(26, 26)
			QuestItemButton:SetTemplate()
			QuestItemButton:CreateShadow()
			QuestItemButton:StyleButton()
			QuestItemButton:SetShadowOverlay(26, 26)
			QuestItemButton:SetNormalTexture(nil)
			
			if (Icon) then
				Icon:SetTexCoord(unpack(A.TexCoords))
			end
		
			if (Count) then
				Count:ClearAllPoints()
				Count:Point("BOTTOMRIGHT", QuestItemButton, 0, 3)
				Count:SetFontTemplate("Default")
			end

			QuestItemButton.IsSkinned = true
		end
	end
end
	
function ObjectiveTracker:UpdateProgressBar(_, line) 
	local Progress = line.ProgressBar
	local Bar = Progress.Bar
	
	if (Bar) then
		local Label = Bar.Label
		local Icon = Bar.Icon
		local IconBG = Bar.IconBG
		local Backdrop = Bar.BarBG
		local Glow = Bar.BarGlow
		local Sheen = Bar.Sheen
		local Frame = Bar.BarFrame
		local Frame2 = Bar.BarFrame2
		local Frame3 = Bar.BarFrame3
		local BorderLeft = Bar.BorderLeft
		local BorderRight = Bar.BorderRight
		local BorderMid = Bar.BorderMid
	
		if not (Bar.IsSkinned) then
			if (Backdrop) then Backdrop:Hide() Backdrop:SetAlpha(0) end
			if (IconBG) then IconBG:Hide() IconBG:SetAlpha(0) end
			if (Glow) then Glow:Hide() end
			if (Sheen) then Sheen:Hide() end
			if (Frame) then Frame:Hide() end
			if (Frame2) then Frame2:Hide() end
			if (Frame3) then Frame3:Hide() end
			if (BorderLeft) then BorderLeft:SetAlpha(0) end
			if (BorderRight) then BorderRight:SetAlpha(0) end
			if (BorderMid) then BorderMid:SetAlpha(0) end
	
			Bar:Height(20)
			Bar:SetStatusBarTexture(C.Media.Blank)
			Bar:SetTemplate()
			Bar:CreateShadow()
		
			Bar.NewBackdrop = CreateFrame("Frame", nil, Bar)
			Bar.NewBackdrop:SetInside()
			Bar.NewBackdrop:SetFrameLevel(Bar:GetFrameLevel() - 1)
			Bar.NewBackdrop:SetBackdrop({
				bgFile = C.Media.Blank,
			})
			Bar.NewBackdrop:SetBackdropColor(unpack(C.General.BackdropColor))
		
			if (Label) then
				Label:ClearAllPoints()
				Label:Point("CENTER", Bar, 0, 0)
				Label:SetFontTemplate("Default")
			end
	
			if (Icon) then
				Icon:Size(20, 20)
				Icon:SetMask("")
				Icon:SetTexCoord(unpack(A.TexCoords))
				Icon:ClearAllPoints()
				Icon:Point("RIGHT", Bar, 26, 0)
		
				if not (Bar.NewBorder) then
					Bar.NewBorder = CreateFrame("Frame", nil, Bar)
					Bar.NewBorder:SetTemplate()
					Bar.NewBorder:CreateShadow()
					Bar.NewBorder:SetOutside(Icon)
					Bar.NewBorder:SetShown(Icon:IsShown())
				end
			end
		
			Bar.IsSkinned = true
		elseif (Icon and Bar.NewBorder) then
			Bar.NewBorder:SetShown(Icon:IsShown())
		end
	end
end

function ObjectiveTracker:UpdateProgressBarColors(Min)
	if (self.Bar and Min) then		
		local R, G, B = A.ColorGradient(Min, 100, 0.8, 0, 0, 0.8, 0.8, 0, 0, 0.8, 0)
		self.Bar:SetStatusBarColor(R, G, B)
	end
end

local function SkinGroupFindButton(block)
	local HasGroupFinderButton = block.hasGroupFinderButton
	local GroupFinderButton = block.groupFinderButton

	if (HasGroupFinderButton and GroupFinderButton) then
		if not (GroupFinderButton.IsSkinned) then
			GroupFinderButton:SkinButton()
			GroupFinderButton:Size(18)
	
			GroupFinderButton.IsSkinned = true
		end
	end
end

local function UpdatePositions(block)
	local GroupFinderButton = block.groupFinderButton
	local ItemButton = block.itemButton

	if (ItemButton) then
		local PointA, PointB, PointC, PointD, PointE = ItemButton:GetPoint()
		ItemButton:Point(PointA, PointB, PointC, 9, -9)
	end
	
	if (GroupFinderButton) then
		local GPointA, GPointB, GPointC, GPointD, GPointE = GroupFinderButton:GetPoint()
		GroupFinderButton:Point(GPointA, GPointB, GPointC, -262, -4)
	end
end

function ObjectiveTracker:AddHooks()
	hooksecurefunc("ObjectiveTracker_Update", self.Skin)
	hooksecurefunc("ScenarioBlocksFrame_OnLoad", self.SkinScenario)
	hooksecurefunc(SCENARIO_CONTENT_TRACKER_MODULE, "Update", self.SkinScenario)
	hooksecurefunc(QUEST_TRACKER_MODULE, "SetBlockHeader", self.UpdateQuestItem)
	hooksecurefunc(WORLD_QUEST_TRACKER_MODULE, "AddObjective", self.UpdateQuestItem)
	hooksecurefunc(DEFAULT_OBJECTIVE_TRACKER_MODULE, "AddProgressBar", self.UpdateProgressBar)
	hooksecurefunc(BONUS_OBJECTIVE_TRACKER_MODULE, "AddProgressBar", self.UpdateProgressBar)
	hooksecurefunc(WORLD_QUEST_TRACKER_MODULE, "AddProgressBar", self.UpdateProgressBar)
	hooksecurefunc(SCENARIO_TRACKER_MODULE, "AddProgressBar", self.UpdateProgressBar)
	hooksecurefunc("BonusObjectiveTrackerProgressBar_SetValue", self.UpdateProgressBarColors)
	hooksecurefunc("ObjectiveTrackerProgressBar_SetValue", self.UpdateProgressBarColors)
	hooksecurefunc("ScenarioTrackerProgressBar_SetValue", self.UpdateProgressBarColors)
	hooksecurefunc("QuestObjectiveSetupBlockButton_FindGroup", SkinGroupFindButton)
	hooksecurefunc("QuestObjectiveSetupBlockButton_AddRightButton", UpdatePositions)
end

function ObjectiveTracker:Enable()
	--if (C.Misc.ObjectiveTrackerMod) then
		self:AddHooks()
	--end

	self:CreateToggleButtons()
	self:SetPoint()
end

--Misc.ObjectiveTracker = ObjectiveTracker